==> brmo-stufbg204-1.5.1-sources.jar: nl/egem/stuf/stuf0204/BevestigingsBericht.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}stuurgegevens"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "stuurgegevens"
})
@XmlRootElement(name = "bevestigingsBericht")
public class BevestigingsBericht {

    @XmlElement(required = true)
    protected Stuurgegevens stuurgegevens;

    /**
     * Gets the value of the stuurgegevens property.
     * 
     * @return
     *     possible object is
     *     {@link Stuurgegevens }
     *     
     */
    public Stuurgegevens getStuurgegevens() {
        return stuurgegevens;
    }

    /**
     * Sets the value of the stuurgegevens property.
     * 
     * @param value
     *     allowed object is
     *     {@link Stuurgegevens }
     *     
     */
    public void setStuurgegevens(Stuurgegevens value) {
        this.stuurgegevens = value;
    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/stuf0204/BevestigingsBericht.java <==

package nl.egem.stuf.stuf0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.egem.nl/StUF/StUF0204}stuurgegevens"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "stuurgegevens"
})
@XmlRootElement(name = "bevestigingsBericht")
public class BevestigingsBericht {

    @XmlElement(required = true)
    protected Stuurgegevens stuurgegevens;

    /**
     * Gets the value of the stuurgegevens property.
     * 
     * @return
     *     possible object is
     *     {@link Stuurgegevens }
     *     
     */
    public Stuurgegevens getStuurgegevens() {
        return stuurgegevens;
    }

    /**
     * Sets the value of the stuurgegevens property.
     * 
     * @param value
     *     allowed object is
     *     {@link Stuurgegevens }
     *     
     */
    public void setStuurgegevens(Stuurgegevens value) {
        this.stuurgegevens = value;
    }

}
